# Auto-generated by Charmonizer. 
# DO NOT EDIT THIS FILE!!

package Charmony;
use strict;
use warnings;

my %defs;

sub config { \%defs }

# BuildEnv
$defs{'CC'} = 'cc';
$defs{'CFLAGS'} = ' -fno-common -DPERL_DARWIN -mmacosx-version-min=12.4 -fno-strict-aliasing -pipe -fstack-protector-strong -DPERL_USE_SAFE_PUTENV -I/Users/pkarman/perl5/perlbrew/perls/perl-5.36.0/lib/5.36.0/darwin-2level/CORE';
$defs{'EXTRA_CFLAGS'} = '-pedantic -Wall -Wextra -Wno-variadic-macros -DPERL_GCC_PEDANTIC -std=gnu99 -D_GNU_SOURCE -fvisibility=hidden -DCFISH_NOTHREADS';

# DirManip
$defs{'HAS_DIRENT_H'} = undef;
$defs{'HAS_DIRENT_D_NAMLEN'} = undef;
$defs{'HAS_DIRENT_D_TYPE'} = undef;
$defs{'makedir(_dir, _mode)'} = 'mkdir(_dir, _mode)';
$defs{'MAKEDIR_MODE_IGNORED'} = '0';
$defs{'DIR_SEP'} = '"/"';
$defs{'DIR_SEP_CHAR'} = '\'/\'';
$defs{'REMOVE_ZAPS_DIRS'} = undef;

# Headers
$defs{'HAS_POSIX'} = undef;
$defs{'HAS_C89'} = undef;
$defs{'HAS_C90'} = undef;
$defs{'HAS_CPIO_H'} = undef;
$defs{'HAS_DIRENT_H'} = undef;
$defs{'HAS_FCNTL_H'} = undef;
$defs{'HAS_GRP_H'} = undef;
$defs{'HAS_PWD_H'} = undef;
$defs{'HAS_REGEX_H'} = undef;
$defs{'HAS_SCHED_H'} = undef;
$defs{'HAS_SYS_STAT_H'} = undef;
$defs{'HAS_SYS_TIME_H'} = undef;
$defs{'HAS_SYS_TIMES_H'} = undef;
$defs{'HAS_SYS_TYPES_H'} = undef;
$defs{'HAS_SYS_UTSNAME_H'} = undef;
$defs{'HAS_SYS_WAIT_H'} = undef;
$defs{'HAS_TAR_H'} = undef;
$defs{'HAS_TERMIOS_H'} = undef;
$defs{'HAS_UNISTD_H'} = undef;
$defs{'HAS_UTIME_H'} = undef;
$defs{'HAS_ASSERT_H'} = undef;
$defs{'HAS_CTYPE_H'} = undef;
$defs{'HAS_ERRNO_H'} = undef;
$defs{'HAS_FLOAT_H'} = undef;
$defs{'HAS_LIMITS_H'} = undef;
$defs{'HAS_LOCALE_H'} = undef;
$defs{'HAS_MATH_H'} = undef;
$defs{'HAS_SETJMP_H'} = undef;
$defs{'HAS_SIGNAL_H'} = undef;
$defs{'HAS_STDARG_H'} = undef;
$defs{'HAS_STDDEF_H'} = undef;
$defs{'HAS_STDIO_H'} = undef;
$defs{'HAS_STDLIB_H'} = undef;
$defs{'HAS_STRING_H'} = undef;
$defs{'HAS_TIME_H'} = undef;
$defs{'HAS_PTHREAD_H'} = undef;

# AtomicOps
$defs{'HAS_LIBKERN_OSATOMIC_H'} = undef;
$defs{'HAS_OSATOMIC_CAS_PTR'} = undef;

# FuncMacro
$defs{'HAS_FUNC_MACRO'} = undef;
$defs{'FUNC_MACRO'} = '__func__';
$defs{'HAS_ISO_FUNC_MACRO'} = undef;
$defs{'HAS_GNUC_FUNC_MACRO'} = undef;
$defs{'INLINE'} = '__inline';

# Booleans
$defs{'HAS_STDBOOL_H'} = undef;

# Integers
$defs{'LITTLE_END'} = undef;
$defs{'HAS_INTTYPES_H'} = undef;
$defs{'HAS_STDINT_H'} = undef;
$defs{'HAS_LONG_LONG'} = undef;
$defs{'SIZEOF_CHAR'} = '1';
$defs{'SIZEOF_SHORT'} = '2';
$defs{'SIZEOF_INT'} = '4';
$defs{'SIZEOF_LONG'} = '8';
$defs{'SIZEOF_PTR'} = '8';
$defs{'SIZEOF_SIZE_T'} = '8';
$defs{'SIZEOF_LONG_LONG'} = '8';
$defs{'HAS_INT8_T'} = undef;
$defs{'HAS_INT16_T'} = undef;
$defs{'HAS_INT32_T'} = undef;
$defs{'HAS_INT64_T'} = undef;
$defs{'PTR_TO_I64(ptr)'} = '((int64_t)(uint64_t)(ptr))';
$defs{'U64_TO_DOUBLE(num)'} = '((double)(num))';

# IntegerTypes

# IntegerLimits

# IntegerLiterals

# IntegerFormatStrings

# Floats
$defs{'F32_INF'} = '(chy_f32inf.f)';
$defs{'F32_NEGINF'} = '(chy_f32neginf.f)';
$defs{'F32_NAN'} = '(chy_f32nan.f)';
$defs{'F64_INF'} = '(chy_f64inf.d)';
$defs{'F64_NEGINF'} = '(chy_f64neginf.d)';
$defs{'F64_NAN'} = '(chy_f64nan.d)';

# LargeFiles
$defs{'HAS_64BIT_OFFSET_TYPE'} = undef;
$defs{'off64_t'} = 'off_t';
$defs{'HAS_64BIT_STDIO'} = undef;
$defs{'fopen64'} = 'fopen';
$defs{'ftello64'} = 'ftello';
$defs{'fseeko64'} = 'fseeko';
$defs{'HAS_64BIT_LSEEK'} = undef;
$defs{'lseek64'} = 'lseek';
$defs{'HAS_64BIT_PREAD'} = undef;
$defs{'pread64'} = 'pread';

# Memory
$defs{'HAS_SYS_MMAN_H'} = undef;
$defs{'HAS_ALLOCA_H'} = undef;
$defs{'alloca'} = 'alloca';

# VariadicMacros
$defs{'HAS_VARIADIC_MACROS'} = undef;
$defs{'HAS_ISO_VARIADIC_MACROS'} = undef;
$defs{'HAS_GNUC_VARIADIC_MACROS'} = undef;

# LocalDefinitions
$defs{'EXTRA_LDFLAGS'} = '';

$defs{'CORE_OBJECTS'} = '../core/Clownfish/TestHarness/TestUtils.o ../core/Clownfish/TestHarness/TestSuite.o ../core/Clownfish/TestHarness/TestSuiteRunner.o ../core/Clownfish/TestHarness/TestBatchRunner.o ../core/Clownfish/TestHarness/TestFormatter.o ../core/Clownfish/Boolean.o ../core/Clownfish/Class.o ../core/Clownfish/Util/Memory.o ../core/Clownfish/Util/SortUtils.o ../core/Clownfish/Util/Atomic.o ../core/Clownfish/Vector.o ../core/Clownfish/CharBuf.o ../core/Clownfish/String.o ../core/Clownfish/Hash.o ../core/Clownfish/PtrHash.o ../core/Clownfish/Err.o ../core/Clownfish/LockFreeRegistry.o ../core/Clownfish/ByteBuf.o ../core/Clownfish/Num.o ../core/Clownfish/Method.o ../core/Clownfish/Blob.o ../core/Clownfish/HashIterator.o ../core/Clownfish/Obj.o ../core/Clownfish.o autogen/source/cfish_parcel.o';
$defs{'TEST_OBJECTS'} = '../test/Clownfish/Test/TestErr.o ../test/Clownfish/Test/TestMethod.o ../test/Clownfish/Test/Util/TestAtomic.o ../test/Clownfish/Test/Util/TestMemory.o ../test/Clownfish/Test/TestHash.o ../test/Clownfish/Test/TestHashIterator.o ../test/Clownfish/Test/TestNum.o ../test/Clownfish/Test/TestLockFreeRegistry.o ../test/Clownfish/Test/TestByteBuf.o ../test/Clownfish/Test/TestObj.o ../test/Clownfish/Test/TestVector.o ../test/Clownfish/Test/TestPtrHash.o ../test/Clownfish/Test/TestBlob.o ../test/Clownfish/Test/TestClass.o ../test/Clownfish/Test/TestCharBuf.o ../test/Clownfish/Test/TestString.o ../test/Clownfish/Test/TestHost.o ../test/Clownfish/Test/TestBoolean.o ../test/Clownfish/Test.o ../test/TestClownfish.o autogen/source/testcfish_parcel.o';

1;

